==> aws-sdk-cpp-1.9.365-2-x86_64.pkg.tar.zst: usr/include/aws/ce/CostExplorerErrors.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once

#include <aws/core/client/AWSError.h>
#include <aws/core/client/CoreErrors.h>
#include <aws/ce/CostExplorer_EXPORTS.h>

namespace Aws
{
namespace CostExplorer
{
enum class CostExplorerErrors
{
  //From Core//
  //////////////////////////////////////////////////////////////////////////////////////////
  INCOMPLETE_SIGNATURE = 0,
  INTERNAL_FAILURE = 1,
  INVALID_ACTION = 2,
  INVALID_CLIENT_TOKEN_ID = 3,
  INVALID_PARAMETER_COMBINATION = 4,
  INVALID_QUERY_PARAMETER = 5,
  INVALID_PARAMETER_VALUE = 6,
  MISSING_ACTION = 7, // SDK should never allow
  MISSING_AUTHENTICATION_TOKEN = 8, // SDK should never allow
  MISSING_PARAMETER = 9, // SDK should never allow
  OPT_IN_REQUIRED = 10,
  REQUEST_EXPIRED = 11,
  SERVICE_UNAVAILABLE = 12,
  THROTTLING = 13,
  VALIDATION = 14,
  ACCESS_DENIED = 15,
  RESOURCE_NOT_FOUND = 16,
  UNRECOGNIZED_CLIENT = 17,
  MALFORMED_QUERY_STRING = 18,
  SLOW_DOWN = 19,
  REQUEST_TIME_TOO_SKEWED = 20,
  INVALID_SIGNATURE = 21,
  SIGNATURE_DOES_NOT_MATCH = 22,
  INVALID_ACCESS_KEY_ID = 23,
  REQUEST_TIMEOUT = 24,
  NETWORK_CONNECTION = 99,

  UNKNOWN = 100,
  ///////////////////////////////////////////////////////////////////////////////////////////

  BILL_EXPIRATION= static_cast<int>(Aws::Client::CoreErrors::SERVICE_EXTENSION_START_RANGE) + 1,
  DATA_UNAVAILABLE,
  INVALID_NEXT_TOKEN,
  LIMIT_EXCEEDED,
  REQUEST_CHANGED,
  SERVICE_QUOTA_EXCEEDED,
  TOO_MANY_TAGS,
  UNKNOWN_MONITOR,
  UNKNOWN_SUBSCRIPTION,
  UNRESOLVABLE_USAGE_UNIT
};

class AWS_COSTEXPLORER_API CostExplorerError : public Aws::Client::AWSError<CostExplorerErrors>
{
public:
  CostExplorerError() {}
  CostExplorerError(const Aws::Client::AWSError<Aws::Client::CoreErrors>& rhs) : Aws::Client::AWSError<CostExplorerErrors>(rhs) {}
  CostExplorerError(Aws::Client::AWSError<Aws::Client::CoreErrors>&& rhs) : Aws::Client::AWSError<CostExplorerErrors>(rhs) {}
  CostExplorerError(const Aws::Client::AWSError<CostExplorerErrors>& rhs) : Aws::Client::AWSError<CostExplorerErrors>(rhs) {}
  CostExplorerError(Aws::Client::AWSError<CostExplorerErrors>&& rhs) : Aws::Client::AWSError<CostExplorerErrors>(rhs) {}

  template <typename T>
  T GetModeledError();
};

namespace CostExplorerErrorMapper
{
  AWS_COSTEXPLORER_API Aws::Client::AWSError<Aws::Client::CoreErrors> GetErrorForName(const char* errorName);
}

} // namespace CostExplorer
} // namespace Aws

==> aws-sdk-cpp-1.11.667-1-x86_64.pkg.tar.zst: usr/include/aws/ce/CostExplorerErrors.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once

#include <aws/core/client/AWSError.h>
#include <aws/core/client/CoreErrors.h>
#include <aws/ce/CostExplorer_EXPORTS.h>

namespace Aws
{
namespace CostExplorer
{
enum class CostExplorerErrors
{
  //From Core//
  //////////////////////////////////////////////////////////////////////////////////////////
  INCOMPLETE_SIGNATURE = 0,
  INTERNAL_FAILURE = 1,
  INVALID_ACTION = 2,
  INVALID_CLIENT_TOKEN_ID = 3,
  INVALID_PARAMETER_COMBINATION = 4,
  INVALID_QUERY_PARAMETER = 5,
  INVALID_PARAMETER_VALUE = 6,
  MISSING_ACTION = 7, // SDK should never allow
  MISSING_AUTHENTICATION_TOKEN = 8, // SDK should never allow
  MISSING_PARAMETER = 9, // SDK should never allow
  OPT_IN_REQUIRED = 10,
  REQUEST_EXPIRED = 11,
  SERVICE_UNAVAILABLE = 12,
  THROTTLING = 13,
  VALIDATION = 14,
  ACCESS_DENIED = 15,
  RESOURCE_NOT_FOUND = 16,
  UNRECOGNIZED_CLIENT = 17,
  MALFORMED_QUERY_STRING = 18,
  SLOW_DOWN = 19,
  REQUEST_TIME_TOO_SKEWED = 20,
  INVALID_SIGNATURE = 21,
  SIGNATURE_DOES_NOT_MATCH = 22,
  INVALID_ACCESS_KEY_ID = 23,
  REQUEST_TIMEOUT = 24,
  NETWORK_CONNECTION = 99,

  UNKNOWN = 100,
  ///////////////////////////////////////////////////////////////////////////////////////////

  ANALYSIS_NOT_FOUND= static_cast<int>(Aws::Client::CoreErrors::SERVICE_EXTENSION_START_RANGE) + 1,
  BACKFILL_LIMIT_EXCEEDED,
  BILLING_VIEW_HEALTH_STATUS,
  BILL_EXPIRATION,
  DATA_UNAVAILABLE,
  GENERATION_EXISTS,
  INVALID_NEXT_TOKEN,
  LIMIT_EXCEEDED,
  REQUEST_CHANGED,
  SERVICE_QUOTA_EXCEEDED,
  TOO_MANY_TAGS,
  UNKNOWN_MONITOR,
  UNKNOWN_SUBSCRIPTION,
  UNRESOLVABLE_USAGE_UNIT
};

class AWS_COSTEXPLORER_API CostExplorerError : public Aws::Client::AWSError<CostExplorerErrors>
{
public:
  CostExplorerError() {}
  CostExplorerError(const Aws::Client::AWSError<Aws::Client::CoreErrors>& rhs) : Aws::Client::AWSError<CostExplorerErrors>(rhs) {}
  CostExplorerError(Aws::Client::AWSError<Aws::Client::CoreErrors>&& rhs) : Aws::Client::AWSError<CostExplorerErrors>(rhs) {}
  CostExplorerError(const Aws::Client::AWSError<CostExplorerErrors>& rhs) : Aws::Client::AWSError<CostExplorerErrors>(rhs) {}
  CostExplorerError(Aws::Client::AWSError<CostExplorerErrors>&& rhs) : Aws::Client::AWSError<CostExplorerErrors>(rhs) {}

  template <typename T>
  T GetModeledError();
};

namespace CostExplorerErrorMapper
{
  AWS_COSTEXPLORER_API Aws::Client::AWSError<Aws::Client::CoreErrors> GetErrorForName(const char* errorName);
}

} // namespace CostExplorer
} // namespace Aws
